SNPknock
====================================

SNPknock is a simple Python package for creating knockoffs of hidden Markov models and genetic data. 

This package implements the algorithms described in the following papers:

 - "Gene hunting with hidden Markov model knockoffs", Sesia et al., Biometrika, 2019, https://dx.doi.org/10.1093/biomet/asy033
 - "Multi-resolution localization of causal variants across the genome", Sesia et al., bioRxiv, 2019, https://dx.doi.org/10.1101/631390

Feature highlights:

- Generate knockoffs for discrete Markov chains (DMC).
- Generate knockoffs for hidden Markov models (HMM).
- Generate knockoffs for genotype and haplotype data.
- Provides a user-friendly interface for fitting an HMM to genetic data using the software fastPhase.

If you want to learn about applying SNPknock to analyze data from large genome-wide association studies, see *KnockoffZoom*: https://msesia.github.io/knockoffzoom

Released under the GPL-v3 license - see the file LICENSE in the source distribution.
